import {ChangeEvent} from "react";
import {useStepEditor} from "sequential-workflow-designer-react";
import {SwitchStep, TaskStep, WarehouseOptimizationStep} from "./model";

export function StepEditor()
{
   const {type, name, step, properties, isReadonly, setName, setProperty, notifyPropertiesChanged, notifyChildrenChanged} =
      useStepEditor<TaskStep | SwitchStep | WarehouseOptimizationStep>();

   function onNameChanged(e: ChangeEvent)
   {
      setName((e.target as HTMLInputElement).value);
   }

   function onXChanged(e: ChangeEvent)
   {
      setProperty("warehouse", (e.target as HTMLInputElement).value);
   }

   function onYChanged(e: ChangeEvent)
   {
      properties["wmsConnection"] = (e.target as HTMLInputElement).value;
      notifyPropertiesChanged();
   }

   function toggleExtraBranch()
   {
      const switchStep = step as SwitchStep;
      if (switchStep.branches["extra"])
      {
         delete switchStep.branches["extra"];
      }
      else
      {
         switchStep.branches["extra"] = [];
      }
      notifyChildrenChanged();
   }

   return (
      <>
         <h2>Step Editor</h2>
         <h3>{type}</h3>

         <h4>Pre-Script</h4>
         <select>
            <option>Pre Script #1</option>
            <option>Pre Script #2</option>
            <option>Pre Script #3</option>
         </select>

         <h4>Post-Script</h4>
         <select>
            <option>Post Script #1</option>
            <option>Post Script #2</option>
            <option>Post Script #3</option>
         </select>

         {type === "switch" && (
            <>
               <h4>Extra branch</h4>
               <button onClick={toggleExtraBranch} disabled={isReadonly}>
                  Toggle branch
               </button>
            </>
         )}
      </>
   );
}
