import {BranchedStep, Definition, Step} from "sequential-workflow-designer";

export interface WorkflowDefinition extends Definition
{
   properties: {
      alfa?: string;
   };
}

export interface TaskStep extends Step
{
   componentType: "task";
   type: "task";
   properties: {
      x?: string;
      y?: string;
      warehouse?: string;
      wmsConnection?: string;
      wmsSystem?: string;
   };
}

export type OptimizationStepType =
   "determineWarehouseRouting" |
   "determineLineHaulLane" |
   "validateLineItems" |
   "determineCoolingCategory" |
   "validateOptimizationRules" |
   "validateAddress" |
   "determineCarrierService" |
   "determineTNT" |
   "determineOrderServiceDates" |
   "orderMatchesFilterSelector";


export interface WarehouseOptimizationStep extends Step
{
   componentType: "task";
   type: OptimizationStepType;
   properties: {
      x?: string;
      y?: string;
      warehouse?: string;
      wmsConnection?: string;
      wmsSystem?: string;
      isValid?: boolean;
   };
}

export interface SwitchStep extends BranchedStep
{
   componentType: "switch";
   type: "switch";
   properties: {
      x?: string;
      y?: string;
      warehouse?: string;
      wmsConnection?: string;
      wmsSystem?: string;
   };
}

export interface ContainerStep extends Step
{
   componentType: "container";
   type: "container";
   properties: {
      x?: string;
      y?: string;
      warehouse?: string;
      wmsConnection?: string;
      wmsSystem?: string;
   };
   sequence: (WarehouseOptimizationStep | SwitchStep)[];
}
